@@ -6,7 +6,7 @@
           'treetop package, version ', info$Version, ', Released ', info$Date, '\n',
           'This package is based upon work supported by the Department of Defense ',
           'Strategic Environmental Research and Development Program (SERDP) under ',
-          'grants No. RC20-136 and RC-2243.\n',
+          'grants No. RC-2243, RC19-1064 and RC20-1346. \n',
           '##----------------------------------------------------------------##',
           sep="")
   )
